<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:jpluck="http://jpluck.sourceforge.net/XSL">
	<xsl:output method="html" encoding="ISO-8859-1" indent="yes"/>
	<xsl:param name="sort-by-name" select="true()"/>
	<xsl:param name="show-type" select="true()"/>
	<xsl:param name="show-language" select="false()"/>
	<xsl:param name="show-date" select="false()"/>
	<xsl:param name="show-patterns" select="false()"/>
	<xsl:param name="show-image-settings" select="true()"/>
	<xsl:param name="show-link-settings" select="true()"/>
	<xsl:param name="show-schedule" select="true()"/>
	<xsl:template match="/jxl">
		<xsl:variable name="title" select="info/title"/>
		<html>
			<head>
				<style type="text/css">
body {
	font-family: Verdana, Arial, sans-serif;
}

table {
	background: black;
}

td, th {
	background: white;
	text-align: left;
	font-size: small;
}

th.section {
	text-align: center;
}

p.note {
	background: #fffff0;
	border: 1px dashed black;
	padding: 0.5em;
	text-align: center;
}
</style>
				<title>
					<xsl:value-of select="$title"/>
				</title>
			</head>
			<body>
				<p class="note">This JXL has been transformed to a web page. Select <em>View Source</em> to view the JXL source.</p>
				<h1>
					<xsl:choose>
						<xsl:when test="$title">
							<xsl:value-of select="$title"/>
						</xsl:when>
						<xsl:otherwise>JXL</xsl:otherwise>
					</xsl:choose>
				</h1>
				<xsl:if test="info/description">
					<xsl:choose>
						<xsl:when test="info/description/p">
						<xsl:copy-of select="info/description/*"/>
						</xsl:when>
						<xsl:otherwise>
							<p>
							<xsl:apply-templates select="info/description"/>
							</p>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:if test="site|feed">
					<h2>Summary</h2>
					<table border="0" cellpadding="4" cellspacing="1">
						<tr>
							<xsl:choose>
								<xsl:when test="$show-type=true() and $show-language=true()">
									<th class="section" colspan="4">Document</th>
								</xsl:when>
								<xsl:when test="$show-type=true() and $show-date=true()">
									<th class="section" colspan="4">Document</th>
								</xsl:when>
								<xsl:when test="$show-type=false() and $show-date=false()">
									<th class="section" colspan="2">Document</th>
								</xsl:when>
								<xsl:otherwise>
									<th class="section" colspan="3">Document</th>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:if test="$show-schedule=true()">
								<th class="section" colspan="2">Date/Time</th>
							</xsl:if>
							<xsl:if test="$show-link-settings=true()">
								<th class="section" colspan="2">Links</th>
							</xsl:if>
							<xsl:if test="$show-patterns=true()">
								<th class="section" colspan="2">Patterns</th>
							</xsl:if>
							<xsl:if test="$show-image-settings=true()">
								<th class="section" colspan="2">Images</th>
							</xsl:if>
						</tr>
						<tr valign="top">
							<th>Name</th>
							<xsl:if test="$show-type=true()">
								<th>Type</th>
							</xsl:if>
							<th>Categories</th>
							<xsl:if test="$show-language=true()">
								<th>Language</th>
							</xsl:if>
							<xsl:if test="$show-date=true()">
								<th>Date</th>
							</xsl:if>
							<xsl:if test="$show-schedule=true()">
								<th>Schedule</th>
								<th>Last Converted</th>
							</xsl:if>
							<xsl:if test="$show-link-settings=true()">
								<th>Depth</th>
								<th>Restrict</th>
							</xsl:if>
							<xsl:if test="$show-patterns=true()">
								<th>Include</th>
								<th>Exclude</th>
							</xsl:if>
							<xsl:if test="$show-image-settings=true()">
								<th>Embedded</th>
								<th>Standalone</th>
							</xsl:if>
						</tr>
						<xsl:choose>
							<xsl:when test="$sort-by-name=true()">
								<xsl:apply-templates select="site|feed">
									<xsl:sort select="name"/>
								</xsl:apply-templates>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="site|feed"/>
							</xsl:otherwise>
						</xsl:choose>
					</table>
				</xsl:if>
				<xsl:if test="import">
					<h2>Imports</h2>
					<ul>
						<xsl:for-each select="import">
							<li>
								<a href="{@href}">
									<xsl:value-of select="@href"/>
								</a>
							</li>
						</xsl:for-each>
					</ul>
				</xsl:if>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="feed|site|template">
		<tr bgcolor="white" valign="top">
			<td>
				<a href="{uri}" title="{uri}" target="_blank">
					<xsl:value-of select="name"/>
				</a>
			</td>
			<xsl:if test="$show-type=true()">
				<td>
					<xsl:value-of select="name(.)"/>
				</td>
			</xsl:if>
			<td>
				<xsl:apply-templates select="." mode="find">
					<xsl:with-param name="element-name" select="'category'"/>
				</xsl:apply-templates>
			</td>
			<xsl:if test="$show-language=true()">
				<td><xsl:value-of select="@language"/></td>
			</xsl:if>
			<xsl:if test="$show-date=true()">
				<td>
					<xsl:value-of select="@date"/>
				</td>
			</xsl:if>
			<xsl:if test="$show-schedule=true()">
				<td>
					<xsl:apply-templates select="." mode="find">
						<xsl:with-param name="element-name" select="'schedule'"/>
					</xsl:apply-templates>
				</td>
				<td>
					<xsl:value-of select="substring(@lastConverted, 1, 16)"/>
				</td>
			</xsl:if>
			<xsl:if test="$show-link-settings=true()">
				<td>
					<xsl:choose>
						<xsl:when test="uri/@maxDepth">
							<xsl:value-of select="uri/@maxDepth"/>
						</xsl:when>
						<xsl:otherwise>0</xsl:otherwise>
					</xsl:choose>
				</td>
				<td>
					<xsl:value-of select="uri/@restrict"/>
				</td>
			</xsl:if>
			<xsl:if test="$show-patterns=true()">
				<td>
					<xsl:for-each select="include/pattern">
						<xsl:value-of select="."/>
						<xsl:if test="position()&lt;last()">
							<br/>
						</xsl:if>
					</xsl:for-each>
				</td>
				<td>
					<xsl:for-each select="exclude/pattern">
						<xsl:value-of select="."/>
						<xsl:if test="position()&lt;last()">
							<br/>
						</xsl:if>
					</xsl:for-each>
				</td>
			</xsl:if>
			<xsl:if test="$show-image-settings=true()">
				<td>
					<xsl:apply-templates select="." mode="find">
						<xsl:with-param name="element-name" select="'embedded'"/>
					</xsl:apply-templates>
				</td>
				<td>
					<xsl:apply-templates select="." mode="find">
						<xsl:with-param name="element-name" select="'standalone'"/>
					</xsl:apply-templates>
				</td>
			</xsl:if>
		</tr>
	</xsl:template>
	<xsl:template match="embedded|standalone">
		<xsl:if test="@bpp>0">
		<xsl:choose><xsl:when test="@maxWidth"><xsl:value-of select="@maxWidth"/></xsl:when><xsl:otherwise>&lt;unbounded&gt;</xsl:otherwise></xsl:choose>x<xsl:choose><xsl:when test="@maxHeight"><xsl:value-of select="@maxHeight"/></xsl:when><xsl:otherwise>&lt;unbounded&gt;</xsl:otherwise></xsl:choose>x<xsl:value-of select="@bpp"/>bpp
		</xsl:if>
	</xsl:template>
	<!-- This template attempts to find a site/feed or template with a descendant element that has the specified $element-name. -->
	<xsl:template match="*" mode="find">
		<xsl:param name="element-name"/>
		<xsl:variable name="element" select="descendant::*[name()=$element-name]"/>
		<xsl:choose>
			<xsl:when test="$element">
				<xsl:apply-templates select="$element"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="template">
					<xsl:choose>
						<xsl:when test="@template">
							<xsl:value-of select="@template"/>
						</xsl:when>
						<xsl:otherwise>_default</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$element">
						<xsl:apply-templates select="$element"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="not(@id) or @id!='_default'">
							<xsl:apply-templates select="/jxl/template[@id=$template]" mode="find">
								<xsl:with-param name="element-name" select="$element-name"/>
							</xsl:apply-templates>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="schedule">
		<xsl:choose>
			<xsl:when test="hourly">
						Hourly at x:<xsl:apply-templates select="hourly/@minute"/>
			</xsl:when>
			<xsl:when test="daily">
						Daily at <xsl:apply-templates select="daily/@hour"/>:<xsl:apply-templates select="daily/@minute"/>
			</xsl:when>
			<xsl:when test="weekly">
						Every <xsl:value-of select="concat(translate(substring(weekly/@day,1,1), 'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'), substring(weekly/@day,2))"/> at <xsl:apply-templates select="weekly/@hour"/>:<xsl:apply-templates select="weekly/@minute"/>
			</xsl:when>
			<xsl:when test="cron">
				<xsl:value-of select="cron"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="@minute|@hour">
		<xsl:variable name="amount" select="number(.)"/>
		<xsl:if test="$amount&lt;10">0</xsl:if>
		<xsl:value-of select="$amount"/>
	</xsl:template>
</xsl:stylesheet>
